@@ -10,7 +10,7 @@ from tornado import stack_context
 from tornado.ioloop import IOLoop
 
 
-version_tuple = (0, 3)
+version_tuple = (0, 4)
 
 version = '.'.join(map(str, version_tuple))
 """Current version of Toro."""
@@ -587,7 +587,7 @@ class JoinableQueue(Queue):
       - `io_loop`: Optional custom IOLoop.
     """
     def __init__(self, maxsize=None, io_loop=None):
-        Queue.__init__(self, maxsize, io_loop)
+        Queue.__init__(self, maxsize=maxsize, io_loop=io_loop)
         self.unfinished_tasks = 0
         self._finished = Event(io_loop)
         self._finished.set()
